"""Energy Grid MCP Server — Stromnetz-Daten für AI-Agents.

Bietet:
- CO2-Intensität des Stromnetzes (UK kostenlos, global mit Key)
- Strommix-Aufschlüsselung (Erneuerbare vs. Fossil)
- Optimale Zeitfenster für energieintensive AI-Tasks
- Großhandels-Strompreise (Deutschland, EU)
- 48h-Prognosen für grüne Energiefenster
"""

from mcp.server.fastmcp import FastMCP

from src.tools.co2_intensity import register_co2_tools
from src.tools.power_mix import register_power_mix_tools
from src.tools.prices import register_price_tools

# FastMCP Server erstellen
mcp = FastMCP(
    "Energy Grid MCP Server",
    instructions=(
        "Gibt AI-Agents Zugriff auf Stromnetz-Daten: "
        "CO2-Intensität, Strommix, Großhandelspreise und optimale Zeitfenster "
        "für energieintensive Tasks. UK-Daten kostenlos ohne Key. "
        "Globale Daten via Electricity Maps (ELECTRICITY_MAPS_TOKEN). "
        "EU-Preise via ENTSO-E (ENTSOE_TOKEN)."
    ),
)

# Tool-Gruppen registrieren
register_co2_tools(mcp)
register_power_mix_tools(mcp)
register_price_tools(mcp)


def main():
    """Server starten."""
    mcp.run(transport="stdio")


if __name__ == "__main__":
    main()
